###########################################################################
Seeking Contributions
###########################################################################

Known bugs and desirable features for which contributions are most welcome.

Required
********

High Priority
*************

#. Release Docker images with CI.

#. Add badges to `<./README.rst>`_: test coverage, CI status, etc.

Nice to Have
************

#. Documentation via Sphinx with CI to publish to RTFD.
